@@ -2,19 +2,17 @@ import functools
 import re
 import typing
 import urllib.parse
-from collections.abc import Sequence
-from dataclasses import MISSING, asdict, fields
+from dataclasses import asdict
 
 from apispec import yaml_utils
-
 from apispec_plugins.base import types
 
+
 __all__ = (
     "spec_from",
     "load_method_specs",
     "load_specs_from_docstring",
     "path_parser",
-    "dataclass_schema_resolver",
     "base_template",
 )
 
@@ -81,31 +79,6 @@ def path_parser(path, **kwargs):
     return parsed
 
 
-def dataclass_schema_resolver(schema):
-    """A schema resolver for dataclasses."""
-
-    def _resolve_field_type(f):
-        if f.type == str:
-            return "string"
-        if f.type == int:
-            return "integer"
-        if f.type == float:
-            return "number"
-        if f.type == bool:
-            return "boolean"
-        elif isinstance(field.type, Sequence):
-            return "array"
-        return "object"
-
-    definition = {"type": "object", "properties": {}, "required": []}
-    for field in fields(schema):
-        name = field.name
-        definition["properties"][name] = {"type": _resolve_field_type(field)}
-        if field.default == MISSING and field.default_factory == MISSING:
-            definition["required"].append(name)
-    return definition
-
-
 def base_template(
     openapi_version: str,
     info: dict = None,
